#
# spec file for package libftdi0
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define realname libftdi
%define sover 1
%define libname %{realname}%{sover}

Name:           libftdi0
Version:        0.20
Release:        2.7
Summary:        Library to program and control the FTDI USB controller
License:        LGPL-2.1+ AND GPL-2.0-with-classpath-exception
Group:          Hardware/Other
URL:            http://www.intra2net.com/en/developer/libftdi
Source:         http://www.intra2net.com/en/developer/libftdi/download/libftdi-%{version}.tar.gz
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libconfuse-devel
BuildRequires:  libusb-compat-devel
BuildRequires:  pkgconfig
%if 0%{?suse_version} < 1500
BuildRequires:  python-devel
BuildRequires:  python-xml
%endif
BuildRequires:  swig

%description
Library to program and control the FTDI USB controller.
This library is used by many programs accessing FTDI USB-to-RS232 converters.

%package -n %{libname}
Summary:        Library to program and control the FTDI USB controller
Group:          System/Libraries

%description -n %{libname}
Library to program and control the FTDI USB controller.
This library is used by many programs accessing FTDI USB-to-RS232 converters.

%package binding-python
Summary:        Python binding for libftdi
Group:          Development/Languages/Python
Requires:       %{libname} = %{version}
Requires:       swig

%description binding-python
Library to program and control the FTDI USB controller.
This library is used by many programs accessing FTDI USB-to-RS232 converters.

This package provides the python binding for libftdi.

%package devel
Summary:        Header files and static libraries for libftdi
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       libusb-compat-devel

%description devel
Header files and static libraries for libftdi.
This library is used by many programs accessing FTDI USB-to-RS232 converters.

%prep
%setup -q -n %{realname}-%{version}

%build
%configure \
%if 0%{?suse_version} < 1500
    --enable-python-binding \
%endif
    --without-examples
make %{?_smp_mflags}

%install
%make_install
#mkdir -p %{buildroot}%{_mandir}/man3
#cp -p doc/man/man3/[^_]*.3 %{buildroot}%{_mandir}/man3
# delete unnecessary files
find %{buildroot} -type f \( -name '*.a' -o -name '*.la' \) -delete -print
rm -rf %{buildroot}/%{python_sitearch}/ftdi.pyc

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%doc AUTHORS COPYING.GPL COPYING.LIB LICENSE README
%{_libdir}/libftdi*.so.*

%if 0%{?suse_version} < 1500
%files binding-python
%{python_sitearch}/_ftdi.so
%{python_sitearch}/ftdi.py
%{python_sitearch}/%{realname}-%{version}-py%{py_ver}.egg-info
%endif

%files devel
%{_bindir}/libftdi-config
%{_includedir}/ftdi.h
%{_includedir}/ftdi.hpp
%{_libdir}/libftdi*.so
%{_libdir}/pkgconfig/libftdi*.pc
#%{_mandir}/man3/*%{ext_man}

%changelog
* Thu Dec 14 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Disable python build deps when not building python bindins.
* Sat Jun 17 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
-disable Python bindings for Tumbleweed
- update specfile
* Thu Jul  6 2017 mardnh@gmx.de
- Rename package
  - libftdi -> libftdi0
* Fri Jun 23 2017 mardnh@gmx.de
- Initial package, version 0.20
  - based on the libftdi1 package
  - do not package development man-pages since there's a
    naming conflict with the ones from libftdi1-devel
